pub struct GetSessionEndpointFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to GetSessionEndpoint.
Gets a connection endpoint and authentication token for a given session Id.
Implementations
Sourceimpl GetSessionEndpointFluentBuilder
impl GetSessionEndpointFluentBuilder
Sourcepub fn as_input(&self) -> &GetSessionEndpointInputBuilder
pub fn as_input(&self) -> &GetSessionEndpointInputBuilder
Access the GetSessionEndpoint as a reference.
Sourcepub async fn send(
self,
) -> Result<GetSessionEndpointOutput, SdkError<GetSessionEndpointError, HttpResponse>>
pub async fn send( self, ) -> Result<GetSessionEndpointOutput, SdkError<GetSessionEndpointError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<GetSessionEndpointOutput, GetSessionEndpointError, Self>
pub fn customize( self, ) -> CustomizableOperation<GetSessionEndpointOutput, GetSessionEndpointError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn session_id(self, input: impl Into<String>) -> Self
pub fn session_id(self, input: impl Into<String>) -> Self
The session ID.
Sourcepub fn set_session_id(self, input: Option<String>) -> Self
pub fn set_session_id(self, input: Option<String>) -> Self
The session ID.
Sourcepub fn get_session_id(&self) -> &Option<String>
pub fn get_session_id(&self) -> &Option<String>
The session ID.